==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridColumnOptionsSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GridColumnOptionsSectionBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnOptionsSectionBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnOptionsSectionBaseDescriptionMetadata.a == null) {
                GridColumnOptionsSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnOptionsSectionBaseDescriptionMetadata.c(GridColumnOptionsSectionBaseDescriptionMetadata.a);
            }
            if (a.j(GridColumnOptionsSectionBaseDescriptionMetadata.a)) {
                return;
            }
            a.y(GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.b(a);
            a.z("GridColumnOptionsSectionBase", GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
    }
    GridColumnOptionsSectionBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnOptionsSectionBaseDescriptionMetadata, 'GridColumnOptionsSectionBaseDescriptionMetadata');
    GridColumnOptionsSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSectionBaseDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridColumnOptionsSectionBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridColumnOptionsBaseDescriptionMetadata } from "./GridColumnOptionsBaseDescriptionMetadata";
/**
 * @hidden
 */
export let GridColumnOptionsSectionBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridColumnOptionsSectionBaseDescriptionMetadata extends Base {
        static b(a) {
            if (GridColumnOptionsSectionBaseDescriptionMetadata.a == null) {
                GridColumnOptionsSectionBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridColumnOptionsSectionBaseDescriptionMetadata.c(GridColumnOptionsSectionBaseDescriptionMetadata.a);
            }
            if (a.k(GridColumnOptionsSectionBaseDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
        static c(a) {
            GridColumnOptionsBaseDescriptionMetadata.c(a);
        }
        static d(a) {
            GridColumnOptionsSectionBaseDescriptionMetadata.b(a);
            a.ab("GridColumnOptionsSectionBase", GridColumnOptionsSectionBaseDescriptionMetadata.a);
        }
    }
    GridColumnOptionsSectionBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(GridColumnOptionsSectionBaseDescriptionMetadata, 'GridColumnOptionsSectionBaseDescriptionMetadata');
    GridColumnOptionsSectionBaseDescriptionMetadata.a = null;
    return GridColumnOptionsSectionBaseDescriptionMetadata;
})();
